Crate mdbook_ai_pocket_reference

Crate mdbook_ai_pocket_reference 

mdbook-ai-pocket-reference

This crate produces a preprocessor for the rust-lang mdbook project that comprises of various link helpers for the AI-Pocket-Reference project.

Basic Usage

First, install the crate:

cargo install mdbook-ai-pocket-reference

Next, and as with all preprocessor extensions, to include mdbook-ai-pocket-reference in your book, add the following to your book.toml:

[preprocessor.ai-pocket-reference]
command = " mdbook-ai-pocket-reference"

In order to add an author or list of authors in your chapter, there is currently one supported helper:

<!-- for including ai-pocket-reference header (default) -->
{{#aipr_header}}

<!-- for including ai-pocket-reference header with colab link -->
{{ #aipr_header colab=nlp/lora.ipynb}}

For more details see the project’s README

Re-exports

pub use ai_pocket_reference::AIPRPreprocessor;

Modules

ai_pocket_reference